(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    248221,       4859]
NotebookOptionsPosition[    240016,       4745]
NotebookOutlinePosition[    240575,       4766]
CellTagsIndexPosition[    240532,       4763]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"92dacf14-7124-4cac-86e4-4c629a231b50"],

Cell["Chapter 3, Section 3.9, Figures 3.18-19", "Section",
 CellChangeTimes->{{3.857287484952321*^9, 
  3.857287489287573*^9}},ExpressionUUID->"4f77843a-67da-410e-af6e-\
c6014724a7c5"],

Cell[TextData[{
 "First we define a function, ",
 StyleBox["ThreeBodyOrbit2D",
  FontWeight->"Bold"],
 ", to solve the planar, circular, restricted, three-body problem for a given \
initial position, ",
 StyleBox["(x0,y0)",
  FontWeight->"Bold"],
 ", and initial velocity in the rotating frame ",
 StyleBox["(xd0,yd0)",
  FontWeight->"Bold"],
 ". The quantity ",
 StyleBox["tmax",
  FontWeight->"Bold"],
 " is the number of orbital periods over which the numerical integration \
takes place and ",
 StyleBox["muval",
  FontWeight->"Bold"],
 " is the value of the mass \[Mu]."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.8572876196063337`*^9}, {3.857287661973275*^9, 
  3.8572876720524817`*^9}, {3.858499144172565*^9, 3.8584991451311703`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"650c7ef4-5d09-4557-8f96-fac6bc56fd38"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ThreeBodyOrbit2D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x0_", ",", " ", "y0_", ",", " ", "xd0_", ",", " ", "yd0_"}], 
     "}"}], ",", " ", "muval_", ",", " ", "tmax_", ",", " ", "\n", 
    "                ", 
    RowBox[{"ppoints_", ":", "100"}], ",", " ", 
    RowBox[{"maxsteps_", ":", "\[Infinity]"}]}], "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"sol", ",", 
      RowBox[{"\[Mu]1", "=", 
       RowBox[{"1", "-", "muval"}]}], ",", 
      RowBox[{"\[Mu]2", "=", "muval"}]}], "}"}], ",", "\n", "  ", 
    RowBox[{
     RowBox[{"sol", " ", "=", " ", 
      RowBox[{"NDSolve", "[", "\n", "  ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"x", "''"}], "[", "t", "]"}], "-", 
            RowBox[{"2", "*", 
             RowBox[{
              RowBox[{"y", "'"}], "[", "t", "]"}]}]}], " ", "==", "  ", "\n", 
           "    ", 
           RowBox[{
            RowBox[{"x", "[", "t", "]"}], " ", "-", " ", 
            RowBox[{"\[Mu]1", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "[", "t", "]"}], "+", "\[Mu]2"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Sqrt", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"x", "[", "t", "]"}], "+", "\[Mu]2"}], ")"}], "^",
                    "2"}], "+", 
                  RowBox[{
                   RowBox[{"y", "[", "t", "]"}], "^", "2"}]}], "]"}], "^", 
                "3"}], ")"}]}]}], " ", "-", "\n", "           ", 
            RowBox[{"\[Mu]2", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "[", "t", "]"}], "-", "\[Mu]1"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Sqrt", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"x", "[", "t", "]"}], "-", "\[Mu]1"}], ")"}], "^",
                    "2"}], "+", 
                  RowBox[{
                   RowBox[{"y", "[", "t", "]"}], "^", "2"}]}], "]"}], "^", 
                "3"}], ")"}]}]}]}]}], ",", "\n", "   ", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "''"}], "[", "t", "]"}], "+", 
            RowBox[{"2", "*", 
             RowBox[{
              RowBox[{"x", "'"}], "[", "t", "]"}]}]}], " ", "==", " ", "\n", 
           "    ", 
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], " ", "-", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Mu]1", "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Sqrt", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"x", "[", "t", "]"}], "+", "\[Mu]2"}], ")"}], "^",
                     "2"}], "+", 
                    RowBox[{
                    RowBox[{"y", "[", "t", "]"}], "^", "2"}]}], "]"}], "^", 
                  "3"}], ")"}]}], " ", "+", "\n", "            ", 
               RowBox[{"\[Mu]2", "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Sqrt", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"x", "[", "t", "]"}], "-", "\[Mu]1"}], ")"}], "^",
                     "2"}], "+", 
                    RowBox[{
                    RowBox[{"y", "[", "t", "]"}], "^", "2"}]}], "]"}], "^", 
                  "3"}], ")"}]}]}], ")"}], "*", 
             RowBox[{"y", "[", "t", "]"}]}]}]}], ",", "\n", "   ", 
          RowBox[{
           RowBox[{"x", "[", "0", "]"}], "==", "x0"}], ",", " ", 
          RowBox[{
           RowBox[{"y", "[", "0", "]"}], "==", "y0"}], ",", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "'"}], "[", "0", "]"}], "==", "xd0"}], ",", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "'"}], "[", "0", "]"}], "==", "yd0"}]}], "}"}], ",", 
        "\n", "   ", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", 
          RowBox[{"tmax", "*", "2", "*", "\[Pi]"}]}], "}"}], ",", " ", 
        RowBox[{"MaxSteps", "->", "maxsteps"}]}], "]"}]}], ";", "\n", "   ", 
     RowBox[{"solvals", "=", "\n", "   ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Evaluate", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"t", "/", "2"}], "/", "\[Pi]"}], ",", 
             RowBox[{"x", "[", "t", "]"}], ",", 
             RowBox[{"y", "[", "t", "]"}], ",", 
             RowBox[{
              RowBox[{"x", "'"}], "[", "t", "]"}], ",", 
             RowBox[{
              RowBox[{"y", "'"}], "[", "t", "]"}]}], "}"}], "/.", "sol"}], 
          "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "\n", "   ", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", 
          RowBox[{"tmax", "*", "2", "*", "\[Pi]"}], ",", 
          RowBox[{"2", "*", "\[Pi]", "*", "0.1"}]}], "}"}]}], "]"}]}], 
     ";"}]}], "\n", "]"}]}]], "Input",
 CellChangeTimes->{{3.857280794403254*^9, 3.857280794406035*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"c88db9c9-f1b1-4c27-9ff0-dc9329ac6d58"],

Cell[TextData[{
 "Next we define a function, ",
 StyleBox["pv20e2D",
  FontWeight->"Bold"],
 ", to convert position and velocity to orbital elements in 2D.  This will be \
used to generate the data for the plots shown in Fig.3.19."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"458a1264-a644-4485-8f3a-a92c976285c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"pv2oe2D", "[", 
    RowBox[{"{", 
     RowBox[{"X_", ",", "Y_", ",", "Xd_", ",", "Yd_"}], "}"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "R2", ",", "R", ",", "V2", ",", "V", ",", "RdRd", ",", "hvec", ",", 
       "h2", ",", "h", ",", "Rd", ",", "ac", ",", "ec", ",", "sfc", ",", 
       "cfc", ",", "fc", ",", "\[Omega]c", ",", "cpfc", ",", "cpc", ",", "Ec",
        ",", "Mc", ",", "\[Lambda]c"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"R2", "=", 
       RowBox[{
        RowBox[{"X", "^", "2"}], "+", 
        RowBox[{"Y", "^", "2"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"R", "=", 
       RowBox[{"Sqrt", "[", "R2", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"V2", "=", 
       RowBox[{
        RowBox[{"Xd", "^", "2"}], "+", 
        RowBox[{"Yd", "^", "2"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"V", "=", 
       RowBox[{"Sqrt", "[", "V2", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"RdRd", "=", 
       RowBox[{
        RowBox[{"X", "*", "Xd"}], "+", 
        RowBox[{"Y", "*", "Yd"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"h", "=", 
       RowBox[{
        RowBox[{"X", "*", "Yd"}], "-", 
        RowBox[{"Y", "*", "Xd"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"h2", "=", 
       RowBox[{"h", "*", "h"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Rd", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"RdRd", ">", "0"}], ",", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"V2", "-", 
           RowBox[{"h2", "/", "R2"}]}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"V2", "-", 
            RowBox[{"h2", "/", "R2"}]}], "]"}]}]}], "]"}]}], ";", 
      RowBox[{"ac", "=", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "/", "R"}], "-", "V2"}], ")"}]}]}], ";", 
      RowBox[{"ec", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         RowBox[{"h2", "/", "ac"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"cpfc", "=", 
       RowBox[{"Mod", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ArcTan", "[", 
           RowBox[{"X", ",", "Y"}], "]"}], "/", "Degree"}], ",", "360"}], 
        "]"}]}], ";", 
      RowBox[{"sfc", "=", 
       RowBox[{"ac", "*", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"ec", "^", "2"}]}], ")"}], "/", "h"}], "/", "ec"}], "*", 
        "Rd"}]}], ";", 
      RowBox[{"cfc", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", "ec"}], ")"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"ac", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"ec", "^", "2"}]}], ")"}], "/", "R"}]}], "-", "1"}], 
         ")"}]}]}], ";", 
      RowBox[{"fc", "=", 
       RowBox[{"Mod", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ArcTan", "[", 
           RowBox[{"cfc", ",", "sfc"}], "]"}], "/", "Degree"}], ",", "360"}], 
        "]"}]}], ";", 
      RowBox[{"cpc", "=", 
       RowBox[{"Mod", "[", 
        RowBox[{
         RowBox[{"cpfc", "-", "fc"}], ",", "360"}], "]"}]}], ";", 
      RowBox[{"Ec", "=", 
       RowBox[{
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "ec"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"1", "+", "ec"}], ")"}]}], "]"}], "*", 
          RowBox[{"Tan", "[", 
           RowBox[{
            RowBox[{"fc", "/", "2"}], " ", "\[Degree]"}], "]"}]}], "]"}], "*",
         "2"}]}], ";", 
      RowBox[{"Mc", "=", 
       RowBox[{"Mod", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Ec", "-", 
            RowBox[{"ec", "*", 
             RowBox[{"Sin", "[", "Ec", "]"}]}]}], ")"}], "/", "Degree"}], ",",
          "360"}], "]"}]}], ";", 
      RowBox[{"\[Lambda]c", "=", 
       RowBox[{"Mod", "[", 
        RowBox[{
         RowBox[{"Mc", "+", "cpc"}], ",", "360"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"ac", ",", "ec", ",", "cpc", ",", "\[Lambda]c"}], "}"}]}]}], 
    "\n", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.856772578226177*^9, {3.856772628071865*^9, 3.856772666532971*^9}, {
   3.856772795141695*^9, 3.856772820881796*^9}, {3.856773201360944*^9, 
   3.856773268852584*^9}, 3.856773339823456*^9, {3.856773374757872*^9, 
   3.856773522884894*^9}, {3.856778356594665*^9, 3.856778390747251*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"b7c3501b-9e7f-46a1-98ed-1869ca58e793"],

Cell[TextData[{
 "Next we define a function, ",
 StyleBox["oe20pv2D",
  FontWeight->"Bold"],
 ", to convert orbital elements to position and velocity in 2D.  This is not \
actually needed but will be used to check the conversion process."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
   3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
   3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, 
   3.857287924953463*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"afcf9799-8aa8-4442-9ea2-86f72992117b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"oe2pv2D", "[", 
    RowBox[{"{", 
     RowBox[{"a_", ",", "e_", ",", "\[CurlyPi]_", ",", "\[Lambda]_"}], "}"}], 
    "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Omega]", ",", "ma", ",", "rma", ",", "x", ",", "y", ",", "ea", ",", 
       "eca", ",", "deca", ",", "p1", ",", "p2", ",", "p3", ",", "p", ",", 
       "r", ",", "n", ",", "xd", ",", "yd", ",", "X", ",", "Y", ",", "Xd", 
       ",", "Yd"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ma", "=", 
       RowBox[{"Mod", "[", 
        RowBox[{
         RowBox[{"\[Lambda]", "-", "\[CurlyPi]"}], ",", "360"}], "]"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"ma", "<", "0"}], ",", 
        RowBox[{"ma", "=", 
         RowBox[{"ma", "+", "360"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"rma", "=", 
       RowBox[{"N", "[", 
        RowBox[{"ma", " ", "Degree"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"eca", "=", 
       RowBox[{"ea", "/.", " ", 
        RowBox[{"FindRoot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ea", "-", 
            RowBox[{"e", " ", 
             RowBox[{"Sin", "[", "ea", "]"}]}]}], "==", "rma"}], ",", 
          RowBox[{"{", 
           RowBox[{"ea", ",", "rma"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"deca", "=", 
       RowBox[{"N", "[", 
        RowBox[{"eca", "/", "Degree"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"deca", "<", "0"}], ",", 
        RowBox[{"deca", "=", 
         RowBox[{"deca", "+", "360"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"x", "=", 
       RowBox[{"a", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", "eca", "]"}], "-", "e"}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"y", "=", 
       RowBox[{"a", "*", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "-", 
          RowBox[{"e", "^", "2"}]}], "]"}], "*", 
        RowBox[{"Sin", "[", "eca", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"r", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"n", "=", 
       RowBox[{"a", "^", 
        RowBox[{"(", 
         RowBox[{"-", "1.5"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"xd", "=", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"n", "*", 
           RowBox[{
            RowBox[{"a", "^", "2"}], "/", "r"}]}], ")"}]}], "*", 
        RowBox[{"Sin", "[", "eca", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"yd", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "*", 
          RowBox[{"a", "^", "2"}], "*", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{"1", "-", 
             RowBox[{"e", "^", "2"}]}], "]"}], "/", "r"}]}], ")"}], "*", 
        RowBox[{"Cos", "[", "eca", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"p", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[CurlyPi]", " ", "\[Degree]"}], "]"}], ",", 
           RowBox[{"-", 
            RowBox[{"Sin", "[", 
             RowBox[{"\[CurlyPi]", " ", "\[Degree]"}], "]"}]}]}], "}"}], ",", 
         
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"\[CurlyPi]", " ", "\[Degree]"}], "]"}], ",", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[CurlyPi]", " ", "\[Degree]"}], "]"}]}], "}"}]}], 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"X", ",", "Y"}], "}"}], "=", 
       RowBox[{"p", ".", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Xd", ",", "Yd"}], "}"}], "=", 
       RowBox[{"p", ".", 
        RowBox[{"{", 
         RowBox[{"xd", ",", "yd"}], "}"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"X", ",", "Y", ",", "Xd", ",", "Yd"}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8567762387934437`*^9, 3.8567762662008667`*^9}, {
  3.856776303879339*^9, 3.8567763589294233`*^9}, {3.856776394884996*^9, 
  3.856776451342245*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"64df2525-e3db-43bb-a220-9c66de9ad90e"],

Cell["Set the value of \[Mu] to be 0.001.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287919718926*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8f7181dc-93e0-40cd-89a9-0ca9564828c6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Mu]", " ", "=", " ", "0.001"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Mu]1", " ", "=", " ", 
   RowBox[{"1", " ", "-", " ", "\[Mu]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Mu]2", " ", "=", " ", "\[Mu]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8567722065552197`*^9, 3.856772214783936*^9}, {
   3.8570296760814037`*^9, 3.8570296908349943`*^9}, 3.8570297372317467`*^9},
 CellLabel->"In[4]:=",ExpressionUUID->"ff84ac4e-36e4-4e5f-a9b3-e843b35e1485"],

Cell["\<\
Fig.3.18 shows the semi-major axis as a function of longitude (in the \
rotating frame) for three different starting conditions.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5bb281f7-d07d-45bd-830f-c64b8c58087b"],

Cell["\<\
The first starting condition will generate a horseshoe path in the rotating \
frame.  It is started just beyond the L3 point. \
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.8572881524140472`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c34edbbf-77ac-420c-8359-c05dc910abf2"],

Cell[BoxData[
 RowBox[{"ThreeBodyOrbit2D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.020000"}], ",", "0.000000", ",", "0.000000", ",", 
     "0.030348"}], "}"}], ",", "\[Mu]2", ",", " ", "100"}], "]"}]], "Input",
 CellChangeTimes->{{3.856776832118135*^9, 3.856776832792762*^9}, {
   3.856776938768922*^9, 3.856776939202714*^9}, {3.8567770253479147`*^9, 
   3.856777027342565*^9}, {3.856777105013537*^9, 3.856777106497301*^9}, 
   3.856855615013925*^9, {3.8568559823245897`*^9, 3.856855982894458*^9}, {
   3.856872588721549*^9, 3.856872593267139*^9}, {3.856873134320559*^9, 
   3.856873135142795*^9}, {3.857029113904149*^9, 3.857029116303443*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"036242e4-ec48-4838-be95-6abcc96fae31"],

Cell[TextData[{
 "The solution to the integration is given in the variable ",
 StyleBox["solvals",
  FontWeight->"Bold"],
 " which is now manipulated to isolate the time intervals (for Fig.3.19) and \
the semi-major axis as a function of longitude for the first plot in Fig.3.18."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.857288256413601*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5bc810fc-28da-40bf-ad58-f2eee5639d4b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tvals", "=", 
   RowBox[{"Transpose", "[", "solvals", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856776878302948*^9, 3.856776917543047*^9}, {
   3.856777159643488*^9, 3.856777210267387*^9}, {3.856855617880666*^9, 
   3.85685564075415*^9}, {3.857037638530786*^9, 3.8570376443964252`*^9}, 
   3.857038188427018*^9, {3.857038315626874*^9, 3.857038331586183*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"07963053-128e-4ff4-b3f2-e868971eb586"],

Cell[BoxData[
 RowBox[{
  RowBox[{"time", "=", 
   RowBox[{"tvals", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856777617200272*^9, 3.856777631885687*^9}, {
  3.857038096718294*^9, 3.857038109797103*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"6040ad65-7f50-4193-873c-54d2017aa851"],

Cell[BoxData[
 RowBox[{
  RowBox[{"posvel", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Take", "[", 
     RowBox[{"tvals", ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "5"}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856777559721572*^9, 3.856777586855249*^9}, 
   3.8567776374209642`*^9},
 CellLabel->"In[10]:=",ExpressionUUID->"9898da21-9dc1-46f0-a97e-d2beae9e7ee8"],

Cell["\<\
Transform the position and velocity in the rotating frame to the position and \
velocity in the non-rotating frame.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.8572883158107224`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"dc07cd96-b59d-4dfb-91fc-7d4c8c3961d1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nrposvel", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tvals", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"tvals", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"tvals", "[", 
        RowBox[{"[", "4", "]"}], "]"}], "-", 
       RowBox[{"tvals", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"tvals", "[", 
        RowBox[{"[", "5", "]"}], "]"}], "+", 
       RowBox[{"tvals", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8568726540126677`*^9, 3.856872661062779*^9}, {
  3.8568727038420773`*^9, 3.856872801883152*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"78f128b8-4aef-4f23-9fd5-025ccf2b47d5"],

Cell[TextData[{
 "Convert the result to orbital elements using ",
 StyleBox["pv2oe2D",
  FontWeight->"Bold"],
 " ..."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.85728835549992*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"09796cda-ad0e-4a63-82f1-f193d465d85b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"orbelem", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"pv2oe2D", "[", "#", "]"}], "&"}], ",", "nrposvel"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8567776491656437`*^9, 3.856777677859851*^9}, {
  3.856777811689146*^9, 3.856777817599841*^9}, {3.85687283333974*^9, 
  3.856872834089158*^9}, {3.857037676106819*^9, 3.8570376781007833`*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"fa04635f-d92c-4b11-baae-edcd74dd1ee3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"test2", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"oe2pv2D", "[", "#", "]"}], "&"}], ",", "orbelem"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.856777834848977*^9, 3.8567778872441607`*^9}, {
  3.856872894270173*^9, 3.8568728982900143`*^9}, {3.857037689470943*^9, 
  3.857037691614813*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"057637b9-7c91-4f66-81b1-9683a1ab3d15"],

Cell[TextData[{
 "... and convert back to position and velocity using ",
 StyleBox["oe2pv2D",
  FontWeight->"Bold"],
 " to compare with the original position and velocity."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.85728847789965*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3fbba7cf-1b4d-4708-8d19-1a4055e300ea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"test2", "-", "nrposvel"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.856778040543366*^9, 3.856778053787817*^9}, {
  3.85687291389012*^9, 3.8568729169197598`*^9}, {3.856873178299244*^9, 
  3.8568731925026083`*^9}, {3.8570299508453827`*^9, 3.857029955135626*^9}, {
  3.857038052904256*^9, 3.857038054117461*^9}, {3.8570385598841333`*^9, 
  3.857038560229566*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"3cd9dddf-f352-493b-8c78-3d31dd543767"],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "992", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}],
  Short]], "Output",
 CellChangeTimes->{{3.857038047003747*^9, 3.857038055104005*^9}, {
   3.857038553973206*^9, 3.857038561474853*^9}, 3.857042519561483*^9, 
   3.857292301888781*^9, 3.8583385096719923`*^9, 3.858338599633419*^9, 
   3.8583388726533327`*^9, 3.8583389092968483`*^9, 3.8909028886339817`*^9},
 CellLabel->
  "Out[14]//Short=",ExpressionUUID->"580a9657-d597-409b-813f-842e5502e8bf"]
}, Open  ]],

Cell[TextData[{
 "Now use the results of the integration to derive ",
 StyleBox["longsma",
  FontWeight->"Bold"],
 " (the variation of semi-major axis with longitude) as well as ",
 StyleBox["timesma",
  FontWeight->"Bold"],
 " (the variation of semimajor axes with time) and ",
 StyleBox["timeecc",
  FontWeight->"Bold"],
 " (the variation of eccentricity with time)."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.857288512009613*^9}, {3.8572886677119837`*^9, 3.85728878279226*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"031ef1c2-1471-4cc5-976c-ab3233e99db9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"torbelem", "=", 
   RowBox[{"Transpose", "[", "orbelem", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856873366940699*^9, 3.856873378222859*^9}, {
  3.857037941454194*^9, 3.857037950093587*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"7e152986-6ed3-4e32-8d94-34e39bf9b9b1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"longsma", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"torbelem", "[", 
       RowBox[{"[", "4", "]"}], "]"}], ",", 
      RowBox[{"torbelem", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856873385198515*^9, 3.8568734752711887`*^9}, {
  3.8570285082352047`*^9, 3.857028509059451*^9}, {3.857028639996279*^9, 
  3.8570286422156363`*^9}, {3.857029372774716*^9, 3.857029373748761*^9}, {
  3.857029868782815*^9, 3.857029869890464*^9}, {3.857037408162849*^9, 
  3.857037410232358*^9}, {3.8570375219516582`*^9, 3.857037524021089*^9}, {
  3.857037957775291*^9, 3.857037959740279*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"7ade9d3c-6e83-43e7-bce0-130d72e8dadf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"timesma", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"time", ",", 
      RowBox[{"torbelem", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8570374720327053`*^9, 3.857037494321999*^9}, {
   3.857037541017335*^9, 3.857037554006329*^9}, 3.857037961269738*^9},
 CellLabel->"In[17]:=",ExpressionUUID->"d5da6a79-e8b8-4633-8bad-cc7570650d83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"timeecc", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"time", ",", 
      RowBox[{"torbelem", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8570374720327053`*^9, 3.857037494321999*^9}, {
   3.857037541017335*^9, 3.857037587260544*^9}, 3.857037963954268*^9, {
   3.857039024598399*^9, 3.8570390250030537`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"8d6ed9af-be41-45aa-a8b7-6b98eda0b6fd"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", 
   RowBox[{
   "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[\"\[Theta]\", \
TraditionalForm], \"errors\" -> {}, \"input\" -> \"\\\\theta\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", "<>", "\"\< (deg.)\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "ylabel", "=", "\"\<\!\(\*StyleBox[\"a\",FontSlant->\"Italic\"]\)\>\""}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.855640306242826*^9, 3.855640313202561*^9}, {
  3.855640391802243*^9, 3.855640398897621*^9}, {3.85564053863629*^9, 
  3.8556406145515633`*^9}, {3.856874675072912*^9, 3.856874721538768*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"48107cdc-9e75-4ac4-a9be-ec604bf227cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "ylabele", "=", "\"\<\!\(\*StyleBox[\"e\",FontSlant->\"Italic\"]\)\>\""}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.855640306242826*^9, 3.855640313202561*^9}, {
  3.855640391802243*^9, 3.855640398897621*^9}, {3.85564053863629*^9, 
  3.8556406145515633`*^9}, {3.856874675072912*^9, 3.856874721538768*^9}, {
  3.857038943481249*^9, 3.85703896929377*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"cabe7008-0de6-452b-bfac-907c23140bad"],

Cell["Plot the variation of semi-major axis with longitude.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.857288512009613*^9}, {3.8572886677119837`*^9, 3.857288817501174*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7e370650-36b8-4f20-942e-c355c9a65402"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"ListLinePlot", "[", 
   RowBox[{"longsma", ",", 
    RowBox[{"Joined", "->", "True"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "360"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.94", ",", "1.06"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"FrameTicks", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "0.94", ",", "0.96", ",", "0.98", ",", "1.0", ",", "1.02", ",", 
           "1.04", ",", "1.06"}], "}"}], ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "0", ",", "60", ",", "120", ",", "180", ",", "240", ",", "300", ",",
            "360"}], "}"}], ",", "None"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{"xlabel", ",", "ylabel"}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8568734141501713`*^9, 3.856873419620586*^9}, {
   3.8568738098811893`*^9, 3.856873978932519*^9}, {3.856874751794046*^9, 
   3.85687476075073*^9}, {3.8568748177067947`*^9, 3.856874821230906*^9}, {
   3.856876505325103*^9, 3.856876527975226*^9}, 3.856876591980289*^9, {
   3.85703151331633*^9, 3.857031514140668*^9}, {3.8570372239788523`*^9, 
   3.8570372273393183`*^9}, {3.857037426373435*^9, 3.85703743024226*^9}, {
   3.857037533817258*^9, 3.857037536081296*^9}, {3.857038590954081*^9, 
   3.857038594265167*^9}, {3.858338412481202*^9, 3.858338453219235*^9}, {
   3.858338524141286*^9, 3.858338526344452*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"18149f9e-4895-4ef4-a145-76fd0bd93beb"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.006944444444444445], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwdmnc8V98fxxUVDVEUIpJRiIZsztsIJXvv9Rl8bD5GVqJBImVEA5VCKPkS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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.9400000000000021},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"a\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\[Theta]\\\", \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\theta\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\) (deg.)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0.94, 
       FormBox["0.94`", TraditionalForm]}, {0.96, 
       FormBox["0.96`", TraditionalForm]}, {0.98, 
       FormBox["0.98`", TraditionalForm]}, {1., 
       FormBox["1.`", TraditionalForm]}, {1.02, 
       FormBox["1.02`", TraditionalForm]}, {1.04, 
       FormBox["1.04`", TraditionalForm]}, {1.06, 
       FormBox["1.06`", TraditionalForm]}}, None}, {{{0, 
       FormBox["0", TraditionalForm]}, {60, 
       FormBox["60", TraditionalForm]}, {120, 
       FormBox["120", TraditionalForm]}, {180, 
       FormBox["180", TraditionalForm]}, {240, 
       FormBox["240", TraditionalForm]}, {300, 
       FormBox["300", TraditionalForm]}, {360, 
       FormBox["360", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 360.}, {0.94, 1.06}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8568734251535797`*^9, 3.856873479232823*^9, {3.85687396562895*^9, 
   3.856873982834934*^9}, 3.8568747699068413`*^9, 3.856874824326271*^9, {
   3.856876515830318*^9, 3.856876530758575*^9}, 3.856876594268114*^9, 
   3.8570298449195213`*^9, 3.857029876602201*^9, {3.857038575922175*^9, 
   3.857038595626828*^9}, 3.857042533749084*^9, 3.85729230231642*^9, {
   3.858338510159066*^9, 3.8583385291076612`*^9}, 3.858338599729064*^9, 
   3.8583388727232122`*^9, 3.8583389098422947`*^9, 3.890902889065624*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"80cd7efd-1fd3-46ae-837f-a6c0ac6ce259"]
}, Open  ]],

Cell["\<\
Plot the variation of semi-major axis with time.  This is Fig.3.19a.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.857288512009613*^9}, {3.8572886677119837`*^9, 3.857288835635854*^9}, {
  3.857290437276742*^9, 3.857290441732265*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7743f314-dab4-46f7-8e76-450e0c047b19"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"psma1", "=", 
  RowBox[{"ListLinePlot", "[", 
   RowBox[{"timesma", ",", 
    RowBox[{"Joined", "->", "True"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "100"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.94", ",", "1.06"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (orbital periods)\>\"", ",", "ylabel"}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8568734141501713`*^9, 3.856873419620586*^9}, {
   3.8568738098811893`*^9, 3.856873978932519*^9}, {3.856874751794046*^9, 
   3.85687476075073*^9}, {3.8568748177067947`*^9, 3.856874821230906*^9}, {
   3.856876505325103*^9, 3.856876527975226*^9}, 3.856876591980289*^9, {
   3.85703151331633*^9, 3.857031514140668*^9}, {3.8570372239788523`*^9, 
   3.8570372273393183`*^9}, {3.857037426373435*^9, 3.85703743024226*^9}, {
   3.857037533817258*^9, 3.857037536081296*^9}, {3.857038590954081*^9, 
   3.857038594265167*^9}, {3.857038758889556*^9, 3.857038768054982*^9}, {
   3.857038798476313*^9, 3.857038811570218*^9}, {3.857038842950913*^9, 
   3.857038858925254*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"10472a61-668e-4fba-a344-c92bda42a11b"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.006944444444444445], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxFW3lczN3/jbJnzdZGpQUl2vfmtE3rNPtSipCiRRJRlBZ7iywRHnsJZQ0p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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.9400000000000021},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"a\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (orbital periods)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 100.}, {0.94, 1.06}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.857038813459947*^9, 3.8570388620258837`*^9, 
  3.8570390347821093`*^9, 3.857292302526802*^9, 3.858338510436708*^9, 
  3.858338599801646*^9, 3.858338872788254*^9, 3.858338910102776*^9, 
  3.8909028891295433`*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"09dcd766-d02c-48f4-85ca-d5f8a07620e7"]
}, Open  ]],

Cell["\<\
Plot the variation of eccentricity with time.  This is Fig.3.19b.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.857288512009613*^9}, {3.8572886677119837`*^9, 3.8572888518519573`*^9}, {
  3.857290445196677*^9, 3.857290451451599*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"cfbc8bb0-5603-4e13-b5f7-005613d76178"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pecc1", "=", 
  RowBox[{"ListLinePlot", "[", 
   RowBox[{"timeecc", ",", 
    RowBox[{"Joined", "->", "True"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "100"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0.018"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{"\"\<Time (orbital periods)\>\"", ",", "ylabele"}], "}"}]}], 
    ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8568734141501713`*^9, 3.856873419620586*^9}, {
   3.8568738098811893`*^9, 3.856873978932519*^9}, {3.856874751794046*^9, 
   3.85687476075073*^9}, {3.8568748177067947`*^9, 3.856874821230906*^9}, {
   3.856876505325103*^9, 3.856876527975226*^9}, 3.856876591980289*^9, {
   3.85703151331633*^9, 3.857031514140668*^9}, {3.8570372239788523`*^9, 
   3.8570372273393183`*^9}, {3.857037426373435*^9, 3.85703743024226*^9}, {
   3.857037533817258*^9, 3.857037536081296*^9}, {3.857038590954081*^9, 
   3.857038594265167*^9}, {3.857038758889556*^9, 3.857038768054982*^9}, {
   3.857038798476313*^9, 3.857038811570218*^9}, {3.857038842950913*^9, 
   3.857038876924556*^9}, {3.857038909654413*^9, 3.857038917364018*^9}, 
   3.857039004633821*^9, {3.857039039823279*^9, 3.857039041292294*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"36dc0b2e-21a8-43ab-a68f-31094d6e8e27"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.006944444444444445], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1W3lcjIv3ThGSraJClBQq2tOi5pn2pmmafaZVe2lXke2SpEgUhZs1JFxb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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"e\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Time (orbital periods)\"", HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 100.}, {0., 0.018}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.857038921758008*^9, 3.857039009727721*^9, 
  3.857039042951145*^9, 3.857292302578701*^9, 3.858338510493166*^9, 
  3.858338599866474*^9, 3.858338872851351*^9, 3.858338910169641*^9, 
  3.89090288933181*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"fe910451-3766-4799-a600-0acfe4c4c913"]
}, Open  ]],

Cell["\<\
Now calculate the numerical solution for a medium amplitude tadpole orbit.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.857288512009613*^9}, {3.8572886677119837`*^9, 3.857288835635854*^9}, {
  3.857288878522275*^9, 3.857288907111742*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"358fc344-9019-445e-be42-802187f91f3f"],

Cell[BoxData[
 RowBox[{"ThreeBodyOrbit2D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.707107"}], ",", "0.707107", ",", "0.000354", ",", 
     "0.000354"}], "}"}], ",", "\[Mu]2", ",", " ", "100"}], "]"}]], "Input",
 CellChangeTimes->{{3.856776832118135*^9, 3.856776832792762*^9}, {
   3.856776938768922*^9, 3.856776939202714*^9}, {3.8567770253479147`*^9, 
   3.856777027342565*^9}, {3.856777105013537*^9, 3.856777106497301*^9}, 
   3.856855615013925*^9, {3.8568559823245897`*^9, 3.856855982894458*^9}, {
   3.856872588721549*^9, 3.856872593267139*^9}, {3.856873134320559*^9, 
   3.856873135142795*^9}, {3.857029113904149*^9, 3.857029116303443*^9}, {
   3.857039226007338*^9, 3.857039235029792*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"5dbba630-5f31-4312-bf15-d5841d68e388"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tvals", "=", 
   RowBox[{"Transpose", "[", "solvals", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856776878302948*^9, 3.856776917543047*^9}, {
   3.856777159643488*^9, 3.856777210267387*^9}, {3.856855617880666*^9, 
   3.85685564075415*^9}, {3.857037638530786*^9, 3.8570376443964252`*^9}, 
   3.857038188427018*^9, {3.857038315626874*^9, 3.857038331586183*^9}, {
   3.857039242829624*^9, 3.857039244135728*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"0d7e993f-32d2-4d08-a115-9ba2c0cd1a6a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"time", "=", 
   RowBox[{"tvals", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856777617200272*^9, 3.856777631885687*^9}, {
  3.857038096718294*^9, 3.857038109797103*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"a7f96597-2623-4b3a-b3b3-1d7ee9df06d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"posvel", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Take", "[", 
     RowBox[{"tvals", ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "5"}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856777559721572*^9, 3.856777586855249*^9}, 
   3.8567776374209642`*^9},
 CellLabel->"In[28]:=",ExpressionUUID->"e5ad91bb-a2ae-470d-b2ad-88c581fcf642"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nrposvel", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tvals", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"tvals", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"tvals", "[", 
        RowBox[{"[", "4", "]"}], "]"}], "-", 
       RowBox[{"tvals", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"tvals", "[", 
        RowBox[{"[", "5", "]"}], "]"}], "+", 
       RowBox[{"tvals", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8568726540126677`*^9, 3.856872661062779*^9}, {
  3.8568727038420773`*^9, 3.856872801883152*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"0ddc5218-dec8-4b6b-a19c-ca955d616394"],

Cell[BoxData[
 RowBox[{
  RowBox[{"orbelem", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"pv2oe2D", "[", "#", "]"}], "&"}], ",", "nrposvel"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8567776491656437`*^9, 3.856777677859851*^9}, {
  3.856777811689146*^9, 3.856777817599841*^9}, {3.85687283333974*^9, 
  3.856872834089158*^9}, {3.857037676106819*^9, 3.8570376781007833`*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"471e8591-1665-49e8-aa11-134aae8a9798"],

Cell[BoxData[
 RowBox[{
  RowBox[{"test2", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"oe2pv2D", "[", "#", "]"}], "&"}], ",", "orbelem"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.856777834848977*^9, 3.8567778872441607`*^9}, {
  3.856872894270173*^9, 3.8568728982900143`*^9}, {3.857037689470943*^9, 
  3.857037691614813*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"16fcfd49-203d-47e3-bd76-f62ecaf932f5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"test2", "-", "nrposvel"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.856778040543366*^9, 3.856778053787817*^9}, {
  3.85687291389012*^9, 3.8568729169197598`*^9}, {3.856873178299244*^9, 
  3.8568731925026083`*^9}, {3.8570299508453827`*^9, 3.857029955135626*^9}, {
  3.857038052904256*^9, 3.857038054117461*^9}, {3.8570385598841333`*^9, 
  3.857038560229566*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"601e3925-4822-45c8-b1d6-28ff74fbbf14"],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "992", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}],
  Short]], "Output",
 CellChangeTimes->{{3.857038047003747*^9, 3.857038055104005*^9}, {
   3.857038553973206*^9, 3.857038561474853*^9}, 3.857039263664953*^9, 
   3.8572923029991617`*^9, 3.858338511037209*^9, 3.858338600319714*^9, 
   3.8583388733001137`*^9, 3.858338910596346*^9, 3.8909028903057537`*^9},
 CellLabel->
  "Out[32]//Short=",ExpressionUUID->"40695d6c-bb0d-4979-bab3-e77fe0315e73"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"torbelem", "=", 
   RowBox[{"Transpose", "[", "orbelem", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856873366940699*^9, 3.856873378222859*^9}, {
  3.857037941454194*^9, 3.857037950093587*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"9cbb4432-673d-4c55-b54c-42d7cf09b01b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"longsma", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"torbelem", "[", 
       RowBox[{"[", "4", "]"}], "]"}], ",", 
      RowBox[{"torbelem", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856873385198515*^9, 3.8568734752711887`*^9}, {
  3.8570285082352047`*^9, 3.857028509059451*^9}, {3.857028639996279*^9, 
  3.8570286422156363`*^9}, {3.857029372774716*^9, 3.857029373748761*^9}, {
  3.857029868782815*^9, 3.857029869890464*^9}, {3.857037408162849*^9, 
  3.857037410232358*^9}, {3.8570375219516582`*^9, 3.857037524021089*^9}, {
  3.857037957775291*^9, 3.857037959740279*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"c3b65a91-2550-4af4-94fc-48b7eaa676a6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", 
   RowBox[{
   "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[\"\[Theta]\", \
TraditionalForm], \"errors\" -> {}, \"input\" -> \"\\\\theta\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", "<>", "\"\< (deg.)\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "ylabel", "=", "\"\<\!\(\*StyleBox[\"a\",FontSlant->\"Italic\"]\)\>\""}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.855640306242826*^9, 3.855640313202561*^9}, {
  3.855640391802243*^9, 3.855640398897621*^9}, {3.85564053863629*^9, 
  3.8556406145515633`*^9}, {3.856874675072912*^9, 3.856874721538768*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"86f5715d-bb2e-4c16-adf7-295d32917ed0"],

Cell["Plot the variation of semi-major axis with longitude.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.857288512009613*^9}, {3.8572886677119837`*^9, 3.857288817501174*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c8b04b05-94a7-4498-979a-3850b90cfe1a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p2", "=", 
  RowBox[{"ListLinePlot", "[", 
   RowBox[{"longsma", ",", 
    RowBox[{"Joined", "->", "True"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "360"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.94", ",", "1.06"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"FrameTicks", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "0.94", ",", "0.96", ",", "0.98", ",", "1.0", ",", "1.02", ",", 
           "1.04", ",", "1.06"}], "}"}], ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "0", ",", "60", ",", "120", ",", "180", ",", "240", ",", "300", ",",
            "360"}], "}"}], ",", "None"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{"xlabel", ",", "ylabel"}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8568734141501713`*^9, 3.856873419620586*^9}, {
   3.8568738098811893`*^9, 3.856873978932519*^9}, {3.856874751794046*^9, 
   3.85687476075073*^9}, {3.8568748177067947`*^9, 3.856874821230906*^9}, {
   3.856876505325103*^9, 3.856876527975226*^9}, 3.856876591980289*^9, {
   3.85703151331633*^9, 3.857031514140668*^9}, {3.8570372239788523`*^9, 
   3.8570372273393183`*^9}, {3.857037426373435*^9, 3.85703743024226*^9}, {
   3.857037533817258*^9, 3.857037536081296*^9}, {3.857038590954081*^9, 
   3.857038594265167*^9}, {3.857039307285138*^9, 3.857039307703586*^9}, 
   3.858338479787024*^9, 3.858338562551148*^9, {3.85833859331531*^9, 
   3.858338594784483*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"ecc46382-1e47-4786-9274-a8754eaa4fc1"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.006944444444444445], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwd23k8VF8bAHBFUgiVKMlSFMleZDuPfd+3sc3cbCFCSFKUIomsSZEt/QiF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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.9400000000000021},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"a\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\[Theta]\\\", \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\theta\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\) (deg.)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0.94, 
       FormBox["0.94`", TraditionalForm]}, {0.96, 
       FormBox["0.96`", TraditionalForm]}, {0.98, 
       FormBox["0.98`", TraditionalForm]}, {1., 
       FormBox["1.`", TraditionalForm]}, {1.02, 
       FormBox["1.02`", TraditionalForm]}, {1.04, 
       FormBox["1.04`", TraditionalForm]}, {1.06, 
       FormBox["1.06`", TraditionalForm]}}, None}, {{{0, 
       FormBox["0", TraditionalForm]}, {60, 
       FormBox["60", TraditionalForm]}, {120, 
       FormBox["120", TraditionalForm]}, {180, 
       FormBox["180", TraditionalForm]}, {240, 
       FormBox["240", TraditionalForm]}, {300, 
       FormBox["300", TraditionalForm]}, {360, 
       FormBox["360", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 360.}, {0.94, 1.06}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8570393107220783`*^9, 3.857292303052812*^9, 3.858338511110347*^9, 
   3.8583385636426973`*^9, {3.8583385959896393`*^9, 3.85833860038498*^9}, 
   3.858338873361003*^9, 3.858338910657998*^9, 3.8909028904498987`*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"4be84c8d-7df5-4e2a-93a9-00bdddb05f50"]
}, Open  ]],

Cell["\<\
Now calculate the numerical solution for a small amplitude tadpole orbit.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.857288512009613*^9}, {3.8572886677119837`*^9, 3.857288835635854*^9}, {
  3.857288878522275*^9, 3.857288907111742*^9}, {3.857288965164209*^9, 
  3.857288965987473*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a3e94ade-d266-4095-9a66-ae5366c00fad"],

Cell[BoxData[
 RowBox[{"ThreeBodyOrbit2D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.707107", ",", "0.707107", ",", "0.000354", ",", 
     RowBox[{"-", "0.000354"}]}], "}"}], ",", "\[Mu]2", ",", " ", "100"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.856776832118135*^9, 3.856776832792762*^9}, {
   3.856776938768922*^9, 3.856776939202714*^9}, {3.8567770253479147`*^9, 
   3.856777027342565*^9}, {3.856777105013537*^9, 3.856777106497301*^9}, 
   3.856855615013925*^9, {3.8568559823245897`*^9, 3.856855982894458*^9}, {
   3.856872588721549*^9, 3.856872593267139*^9}, {3.856873134320559*^9, 
   3.856873135142795*^9}, {3.857029113904149*^9, 3.857029116303443*^9}, {
   3.857039226007338*^9, 3.857039235029792*^9}, {3.857039368144224*^9, 
   3.857039386287784*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"d471bed1-403a-4527-a88d-eb17475661ac"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tvals", "=", 
   RowBox[{"Transpose", "[", "solvals", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856776878302948*^9, 3.856776917543047*^9}, {
   3.856777159643488*^9, 3.856777210267387*^9}, {3.856855617880666*^9, 
   3.85685564075415*^9}, {3.857037638530786*^9, 3.8570376443964252`*^9}, 
   3.857038188427018*^9, {3.857038315626874*^9, 3.857038331586183*^9}, {
   3.857039242829624*^9, 3.857039244135728*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"ef2dee08-c63c-4cf4-a1ca-54172bb70aae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"time", "=", 
   RowBox[{"tvals", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856777617200272*^9, 3.856777631885687*^9}, {
  3.857038096718294*^9, 3.857038109797103*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"391537d7-cb67-4f46-a8ac-3a57e82f274a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"posvel", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Take", "[", 
     RowBox[{"tvals", ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "5"}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856777559721572*^9, 3.856777586855249*^9}, 
   3.8567776374209642`*^9},
 CellLabel->"In[41]:=",ExpressionUUID->"ff99ef73-7743-4997-852e-b013a92f026b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nrposvel", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tvals", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"tvals", "[", 
       RowBox[{"[", "3", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"tvals", "[", 
        RowBox[{"[", "4", "]"}], "]"}], "-", 
       RowBox[{"tvals", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"tvals", "[", 
        RowBox[{"[", "5", "]"}], "]"}], "+", 
       RowBox[{"tvals", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8568726540126677`*^9, 3.856872661062779*^9}, {
  3.8568727038420773`*^9, 3.856872801883152*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"65867b40-1584-4de5-80c2-1ab58756e62a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"orbelem", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"pv2oe2D", "[", "#", "]"}], "&"}], ",", "nrposvel"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8567776491656437`*^9, 3.856777677859851*^9}, {
  3.856777811689146*^9, 3.856777817599841*^9}, {3.85687283333974*^9, 
  3.856872834089158*^9}, {3.857037676106819*^9, 3.8570376781007833`*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"5995df7d-3585-49b2-937a-7383ea5744b7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"test2", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"oe2pv2D", "[", "#", "]"}], "&"}], ",", "orbelem"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.856777834848977*^9, 3.8567778872441607`*^9}, {
  3.856872894270173*^9, 3.8568728982900143`*^9}, {3.857037689470943*^9, 
  3.857037691614813*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"1ad597dc-f82a-4afe-bf9b-68b162ac6e57"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"test2", "-", "nrposvel"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.856778040543366*^9, 3.856778053787817*^9}, {
  3.85687291389012*^9, 3.8568729169197598`*^9}, {3.856873178299244*^9, 
  3.8568731925026083`*^9}, {3.8570299508453827`*^9, 3.857029955135626*^9}, {
  3.857038052904256*^9, 3.857038054117461*^9}, {3.8570385598841333`*^9, 
  3.857038560229566*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"90453fe4-cb14-4c98-a7f9-a925ede5d97e"],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "992", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}],
  Short]], "Output",
 CellChangeTimes->{{3.857038047003747*^9, 3.857038055104005*^9}, {
   3.857038553973206*^9, 3.857038561474853*^9}, 3.857039263664953*^9, 
   3.857039410930448*^9, 3.857292303496379*^9, 3.858338511594523*^9, 
   3.858338600823381*^9, 3.85833887378695*^9, 3.858338911099573*^9, 
   3.890902890970169*^9},
 CellLabel->
  "Out[45]//Short=",ExpressionUUID->"e8fcd7ba-03d8-4c68-9ef7-9887ed471748"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"torbelem", "=", 
   RowBox[{"Transpose", "[", "orbelem", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856873366940699*^9, 3.856873378222859*^9}, {
  3.857037941454194*^9, 3.857037950093587*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"4d651905-5f4b-46dd-bf97-fbe5fe7742fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"longsma", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"torbelem", "[", 
       RowBox[{"[", "4", "]"}], "]"}], ",", 
      RowBox[{"torbelem", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.856873385198515*^9, 3.8568734752711887`*^9}, {
  3.8570285082352047`*^9, 3.857028509059451*^9}, {3.857028639996279*^9, 
  3.8570286422156363`*^9}, {3.857029372774716*^9, 3.857029373748761*^9}, {
  3.857029868782815*^9, 3.857029869890464*^9}, {3.857037408162849*^9, 
  3.857037410232358*^9}, {3.8570375219516582`*^9, 3.857037524021089*^9}, {
  3.857037957775291*^9, 3.857037959740279*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"415e2ff7-e369-4591-9328-0674593fff3b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", 
   RowBox[{
   "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[\"\[Theta]\", \
TraditionalForm], \"errors\" -> {}, \"input\" -> \"\\\\theta\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", "<>", "\"\< (deg.)\>\""}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "ylabel", "=", "\"\<\!\(\*StyleBox[\"a\",FontSlant->\"Italic\"]\)\>\""}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.855640306242826*^9, 3.855640313202561*^9}, {
  3.855640391802243*^9, 3.855640398897621*^9}, {3.85564053863629*^9, 
  3.8556406145515633`*^9}, {3.856874675072912*^9, 3.856874721538768*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"c1ccd2a5-7a5e-4caf-b766-0264c3681cda"],

Cell["Plot the variation of semi-major axis with longitude.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.857288512009613*^9}, {3.8572886677119837`*^9, 3.857288817501174*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"082b1720-4bae-4cdc-8658-00d706580742"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p3", "=", 
  RowBox[{"ListLinePlot", "[", 
   RowBox[{"longsma", ",", 
    RowBox[{"Joined", "->", "True"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "360"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.94", ",", "1.06"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"FrameTicks", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "0.94", ",", "0.96", ",", "0.98", ",", "1.0", ",", "1.02", ",", 
           "1.04", ",", "1.06"}], "}"}], ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "0", ",", "60", ",", "120", ",", "180", ",", "240", ",", "300", ",",
            "360"}], "}"}], ",", "None"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{"xlabel", ",", "ylabel"}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8568734141501713`*^9, 3.856873419620586*^9}, {
   3.8568738098811893`*^9, 3.856873978932519*^9}, {3.856874751794046*^9, 
   3.85687476075073*^9}, {3.8568748177067947`*^9, 3.856874821230906*^9}, {
   3.856876505325103*^9, 3.856876527975226*^9}, 3.856876591980289*^9, {
   3.85703151331633*^9, 3.857031514140668*^9}, {3.8570372239788523`*^9, 
   3.8570372273393183`*^9}, {3.857037426373435*^9, 3.85703743024226*^9}, {
   3.857037533817258*^9, 3.857037536081296*^9}, {3.857038590954081*^9, 
   3.857038594265167*^9}, {3.857039307285138*^9, 3.857039307703586*^9}, {
   3.857039422963097*^9, 3.8570394233222513`*^9}, 3.8583384903465242`*^9, {
   3.858338574297495*^9, 3.858338579484231*^9}},
 CellLabel->"In[50]:=",ExpressionUUID->"bc0f0102-f49d-48b8-9808-919ab1dbb0fb"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      NCache[
       Rational[1, 120], 0.008333333333333333]], AbsoluteThickness[1.6], 
     LineBox[CompressedData["
1:eJwdm3k4VH8bxm2FskWhRIpCZM0SMQ9pZjCYmaPSIrQqClmLLNlFlCUKUYpK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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.9400000000000021},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"a\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\[Theta]\\\", \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\theta\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\) (deg.)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0.94, 
       FormBox["0.94`", TraditionalForm]}, {0.96, 
       FormBox["0.96`", TraditionalForm]}, {0.98, 
       FormBox["0.98`", TraditionalForm]}, {1., 
       FormBox["1.`", TraditionalForm]}, {1.02, 
       FormBox["1.02`", TraditionalForm]}, {1.04, 
       FormBox["1.04`", TraditionalForm]}, {1.06, 
       FormBox["1.06`", TraditionalForm]}}, None}, {{{0, 
       FormBox["0", TraditionalForm]}, {60, 
       FormBox["60", TraditionalForm]}, {120, 
       FormBox["120", TraditionalForm]}, {180, 
       FormBox["180", TraditionalForm]}, {240, 
       FormBox["240", TraditionalForm]}, {300, 
       FormBox["300", TraditionalForm]}, {360, 
       FormBox["360", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 360.}, {0.94, 1.06}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.857039427349534*^9, 3.857292303550386*^9, 3.858338511653984*^9, {
   3.858338581468148*^9, 3.858338600882839*^9}, 3.858338873846477*^9, 
   3.858338911165667*^9, 3.890902891130988*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"016fca40-4908-4690-be5d-af3358dbe8a9"]
}, Open  ]],

Cell["\<\
Calculate the position of the three Lagrange points, L3, L4 and L5. \
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.857288512009613*^9}, {3.8572886677119837`*^9, 3.857288817501174*^9}, {
  3.857288991697564*^9, 3.857289017917294*^9}, {3.8572903011501427`*^9, 
  3.857290310918083*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6f1c16bb-0dbd-4532-92fb-70ae6bc1761d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lagpts", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"PointSize", "[", "0.01", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"60", ",", "1"}], "}"}], "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"180", ",", "1"}], "}"}], "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"300", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8570395052817297`*^9, 3.857039614824316*^9}},
 CellLabel->"In[51]:=",ExpressionUUID->"627d86bf-36e7-4379-88d0-43ee1865f77e"],

Cell["\<\
Finally display all three plots along with the points L3, L4 and L5.  This is \
Fig.3.18.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857287581462007*^9, 3.857287654240697*^9}, {3.857287691913073*^9, 
  3.8572877505774527`*^9}, {3.857287831458107*^9, 3.857287890483364*^9}, {
  3.857287924953463*^9, 3.857288011879517*^9}, {3.857288097364152*^9, 
  3.857288512009613*^9}, {3.8572886677119837`*^9, 3.857288817501174*^9}, {
  3.857288991697564*^9, 3.857289017917294*^9}, {3.8572903011501427`*^9, 
  3.85729035831549*^9}, {3.8572904155720177`*^9, 3.857290423221758*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3f015b35-648d-4afe-84ef-6d5158bae492"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"p1", ",", "p2", ",", "p3", ",", "lagpts"}], "]"}]], "Input",
 CellChangeTimes->{{3.8570394320230703`*^9, 3.8570394398066177`*^9}, {
  3.8570396073243217`*^9, 3.8570396091549997`*^9}},
 CellLabel->"In[52]:=",ExpressionUUID->"64a90a4b-fc6d-499d-a26e-0158bbf1d895"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.006944444444444445],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwdmnc8V98fxxUVDVEUIpJRiIZsztsIJXvv9Rl8bD5GVqJBImVEA5VCKPkS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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.006944444444444445],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwd23k8VF8bAHBFUgiVKMlSFMleZDuPfd+3sc3cbCFCSFKUIomsSZEt/QiF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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       NCache[
        Rational[1, 120], 0.008333333333333333]], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJwdm3k4VH8bxm2FskWhRIpCZM0SMQ9pZjCYmaPSIrQqClmLLNlFlCUKUYpK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       "]]}}, {{}, {}}}, 
   {RGBColor[1, 0, 0], PointSize[0.01], PointBox[{60, 1}], PointBox[{180, 1}],
     PointBox[{300, 1}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.9400000000000021},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*StyleBox[\\\"a\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\[Theta]\\\", \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\theta\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\) (deg.)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{0.94, 
       FormBox["0.94`", TraditionalForm]}, {0.96, 
       FormBox["0.96`", TraditionalForm]}, {0.98, 
       FormBox["0.98`", TraditionalForm]}, {1., 
       FormBox["1.`", TraditionalForm]}, {1.02, 
       FormBox["1.02`", TraditionalForm]}, {1.04, 
       FormBox["1.04`", TraditionalForm]}, {1.06, 
       FormBox["1.06`", TraditionalForm]}}, None}, {{{0, 
       FormBox["0", TraditionalForm]}, {60, 
       FormBox["60", TraditionalForm]}, {120, 
       FormBox["120", TraditionalForm]}, {180, 
       FormBox["180", TraditionalForm]}, {240, 
       FormBox["240", TraditionalForm]}, {300, 
       FormBox["300", TraditionalForm]}, {360, 
       FormBox["360", TraditionalForm]}}, None}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 360.}, {0.94, 1.06}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.857039442058326*^9, {3.8570396102232647`*^9, 3.857039617151431*^9}, 
   3.857292303581067*^9, 3.8583385116825037`*^9, 3.8583386009116*^9, 
   3.8583388738845797`*^9, 3.858338911193575*^9, 3.890902891187621*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"187bbe8c-f5c5-410b-bca9-de2ef40b805b"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{919, 636},
WindowMargins->{{80, Automatic}, {Automatic, 33}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"d5b2695e-43a7-4d69-be38-5af6a907b850"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"92dacf14-7124-4cac-86e4-4c629a231b50"],
Cell[948, 30, 184, 3, 67, "Section",ExpressionUUID->"4f77843a-67da-410e-af6e-c6014724a7c5"],
Cell[1135, 35, 913, 25, 95, "Text",ExpressionUUID->"650c7ef4-5d09-4557-8f96-fac6bc56fd38"],
Cell[2051, 62, 5710, 148, 346, "Input",ExpressionUUID->"c88db9c9-f1b1-4c27-9ff0-dc9329ac6d58"],
Cell[7764, 212, 519, 12, 76, "Text",ExpressionUUID->"458a1264-a644-4485-8f3a-a92c976285c7"],
Cell[8286, 226, 4791, 132, 472, "Input",ExpressionUUID->"b7c3501b-9e7f-46a1-98ed-1869ca58e793"],
Cell[13080, 360, 600, 13, 76, "Text",ExpressionUUID->"afcf9799-8aa8-4442-9ea2-86f72992117b"],
Cell[13683, 375, 4628, 124, 409, "Input",ExpressionUUID->"64df2525-e3db-43bb-a220-9c66de9ad90e"],
Cell[18314, 501, 373, 6, 53, "Text",ExpressionUUID->"8f7181dc-93e0-40cd-89a9-0ca9564828c6"],
Cell[18690, 509, 485, 10, 73, "Input",ExpressionUUID->"ff84ac4e-36e4-4e5f-a9b3-e843b35e1485"],
Cell[19178, 521, 523, 10, 53, "Text",ExpressionUUID->"5bb281f7-d07d-45bd-830f-c64b8c58087b"],
Cell[19704, 533, 572, 11, 53, "Text",ExpressionUUID->"c34edbbf-77ac-420c-8359-c05dc910abf2"],
Cell[20279, 546, 750, 13, 30, "Input",ExpressionUUID->"036242e4-ec48-4838-be95-6abcc96fae31"],
Cell[21032, 561, 712, 14, 76, "Text",ExpressionUUID->"5bc810fc-28da-40bf-ad58-f2eee5639d4b"],
Cell[21747, 577, 477, 8, 30, "Input",ExpressionUUID->"07963053-128e-4ff4-b3f2-e868971eb586"],
Cell[22227, 587, 321, 7, 30, "Input",ExpressionUUID->"6040ad65-7f50-4193-873c-54d2017aa851"],
Cell[22551, 596, 400, 10, 30, "Input",ExpressionUUID->"9898da21-9dc1-46f0-a97e-d2beae9e7ee8"],
Cell[22954, 608, 561, 11, 53, "Text",ExpressionUUID->"dc07cd96-b59d-4dfb-91fc-7d4c8c3961d1"],
Cell[23518, 621, 826, 22, 30, "Input",ExpressionUUID->"78f128b8-4aef-4f23-9fd5-025ccf2b47d5"],
Cell[24347, 645, 548, 13, 53, "Text",ExpressionUUID->"09796cda-ad0e-4a63-82f1-f193d465d85b"],
Cell[24898, 660, 490, 11, 30, "Input",ExpressionUUID->"fa04635f-d92c-4b11-baae-edcd74dd1ee3"],
Cell[25391, 673, 442, 11, 30, "Input",ExpressionUUID->"057637b9-7c91-4f66-81b1-9683a1ab3d15"],
Cell[25836, 686, 603, 13, 53, "Text",ExpressionUUID->"3fbba7cf-1b4d-4708-8d19-1a4055e300ea"],
Cell[CellGroupData[{
Cell[26464, 703, 518, 9, 30, "Input",ExpressionUUID->"3cd9dddf-f352-493b-8c78-3d31dd543767"],
Cell[26985, 714, 1244, 29, 70, "Output",ExpressionUUID->"580a9657-d597-409b-813f-842e5502e8bf"]
}, Open  ]],
Cell[28244, 746, 848, 19, 76, "Text",ExpressionUUID->"031ef1c2-1471-4cc5-976c-ab3233e99db9"],
Cell[29095, 767, 311, 6, 30, "Input",ExpressionUUID->"7e152986-6ed3-4e32-8d94-34e39bf9b9b1"],
Cell[29409, 775, 785, 16, 30, "Input",ExpressionUUID->"7ade9d3c-6e83-43e7-bce0-130d72e8dadf"],
Cell[30197, 793, 450, 10, 30, "Input",ExpressionUUID->"d5da6a79-e8b8-4633-8bad-cc7570650d83"],
Cell[30650, 805, 502, 11, 30, "Input",ExpressionUUID->"8d6ed9af-be41-45aa-a8b7-6b98eda0b6fd"],
Cell[31155, 818, 723, 15, 53, "Input",ExpressionUUID->"48107cdc-9e75-4ac4-a9be-ec604bf227cb"],
Cell[31881, 835, 469, 9, 30, "Input",ExpressionUUID->"cabe7008-0de6-452b-bfac-907c23140bad"],
Cell[32353, 846, 537, 8, 53, "Text",ExpressionUUID->"7e370650-36b8-4f20-942e-c355c9a65402"],
Cell[CellGroupData[{
Cell[32915, 858, 2053, 47, 94, "Input",ExpressionUUID->"18149f9e-4895-4ef4-a145-76fd0bd93beb"],
Cell[34971, 907, 25336, 456, 249, "Output",ExpressionUUID->"80cd7efd-1fd3-46ae-837f-a6c0ac6ce259"]
}, Open  ]],
Cell[60322, 1366, 609, 11, 53, "Text",ExpressionUUID->"7743f314-dab4-46f7-8e76-450e0c047b19"],
Cell[CellGroupData[{
Cell[60956, 1381, 1613, 33, 73, "Input",ExpressionUUID->"10472a61-668e-4fba-a344-c92bda42a11b"],
Cell[62572, 1416, 17209, 319, 249, "Output",ExpressionUUID->"09dcd766-d02c-48f4-85ca-d5f8a07620e7"]
}, Open  ]],
Cell[79796, 1738, 608, 11, 53, "Text",ExpressionUUID->"cfbc8bb0-5603-4e13-b5f7-005613d76178"],
Cell[CellGroupData[{
Cell[80429, 1753, 1735, 35, 73, "Input",ExpressionUUID->"36dc0b2e-21a8-43ab-a68f-31094d6e8e27"],
Cell[82167, 1790, 18209, 336, 236, "Output",ExpressionUUID->"fe910451-3766-4799-a600-0acfe4c4c913"]
}, Open  ]],
Cell[100391, 2129, 615, 11, 53, "Text",ExpressionUUID->"358fc344-9019-445e-be42-802187f91f3f"],
Cell[101009, 2142, 801, 14, 30, "Input",ExpressionUUID->"5dbba630-5f31-4312-bf15-d5841d68e388"],
Cell[101813, 2158, 528, 9, 30, "Input",ExpressionUUID->"0d7e993f-32d2-4d08-a115-9ba2c0cd1a6a"],
Cell[102344, 2169, 322, 7, 30, "Input",ExpressionUUID->"a7f96597-2623-4b3a-b3b3-1d7ee9df06d0"],
Cell[102669, 2178, 400, 10, 30, "Input",ExpressionUUID->"e5ad91bb-a2ae-470d-b2ad-88c581fcf642"],
Cell[103072, 2190, 826, 22, 30, "Input",ExpressionUUID->"0ddc5218-dec8-4b6b-a19c-ca955d616394"],
Cell[103901, 2214, 490, 11, 30, "Input",ExpressionUUID->"471e8591-1665-49e8-aa11-134aae8a9798"],
Cell[104394, 2227, 442, 11, 30, "Input",ExpressionUUID->"16fcfd49-203d-47e3-bd76-f62ecaf932f5"],
Cell[CellGroupData[{
Cell[104861, 2242, 518, 9, 30, "Input",ExpressionUUID->"601e3925-4822-45c8-b1d6-28ff74fbbf14"],
Cell[105382, 2253, 1242, 29, 70, "Output",ExpressionUUID->"40695d6c-bb0d-4979-bab3-e77fe0315e73"]
}, Open  ]],
Cell[106639, 2285, 311, 6, 30, "Input",ExpressionUUID->"9cbb4432-673d-4c55-b54c-42d7cf09b01b"],
Cell[106953, 2293, 785, 16, 30, "Input",ExpressionUUID->"c3b65a91-2550-4af4-94fc-48b7eaa676a6"],
Cell[107741, 2311, 723, 15, 53, "Input",ExpressionUUID->"86f5715d-bb2e-4c16-adf7-295d32917ed0"],
Cell[108467, 2328, 537, 8, 53, "Text",ExpressionUUID->"c8b04b05-94a7-4498-979a-3850b90cfe1a"],
Cell[CellGroupData[{
Cell[109029, 2340, 2100, 48, 94, "Input",ExpressionUUID->"ecc46382-1e47-4786-9274-a8754eaa4fc1"],
Cell[111132, 2390, 24982, 451, 249, "Output",ExpressionUUID->"4be84c8d-7df5-4e2a-93a9-00bdddb05f50"]
}, Open  ]],
Cell[136129, 2844, 663, 12, 53, "Text",ExpressionUUID->"a3e94ade-d266-4095-9a66-ae5366c00fad"],
Cell[136795, 2858, 848, 15, 30, "Input",ExpressionUUID->"d471bed1-403a-4527-a88d-eb17475661ac"],
Cell[137646, 2875, 528, 9, 30, "Input",ExpressionUUID->"ef2dee08-c63c-4cf4-a1ca-54172bb70aae"],
Cell[138177, 2886, 322, 7, 30, "Input",ExpressionUUID->"391537d7-cb67-4f46-a8ac-3a57e82f274a"],
Cell[138502, 2895, 400, 10, 30, "Input",ExpressionUUID->"ff99ef73-7743-4997-852e-b013a92f026b"],
Cell[138905, 2907, 826, 22, 30, "Input",ExpressionUUID->"65867b40-1584-4de5-80c2-1ab58756e62a"],
Cell[139734, 2931, 490, 11, 30, "Input",ExpressionUUID->"5995df7d-3585-49b2-937a-7383ea5744b7"],
Cell[140227, 2944, 442, 11, 30, "Input",ExpressionUUID->"1ad597dc-f82a-4afe-bf9b-68b162ac6e57"],
Cell[CellGroupData[{
Cell[140694, 2959, 518, 9, 30, "Input",ExpressionUUID->"90453fe4-cb14-4c98-a7f9-a925ede5d97e"],
Cell[141215, 2970, 1261, 30, 70, "Output",ExpressionUUID->"e8fcd7ba-03d8-4c68-9ef7-9887ed471748"]
}, Open  ]],
Cell[142491, 3003, 311, 6, 30, "Input",ExpressionUUID->"4d651905-5f4b-46dd-bf97-fbe5fe7742fe"],
Cell[142805, 3011, 785, 16, 30, "Input",ExpressionUUID->"415e2ff7-e369-4591-9328-0674593fff3b"],
Cell[143593, 3029, 723, 15, 53, "Input",ExpressionUUID->"c1ccd2a5-7a5e-4caf-b766-0264c3681cda"],
Cell[144319, 3046, 537, 8, 53, "Text",ExpressionUUID->"082b1720-4bae-4cdc-8658-00d706580742"],
Cell[CellGroupData[{
Cell[144881, 3058, 2129, 48, 94, "Input",ExpressionUUID->"bc0f0102-f49d-48b8-9808-919ab1dbb0fb"],
Cell[147013, 3108, 24673, 448, 249, "Output",ExpressionUUID->"016fca40-4908-4690-be5d-af3358dbe8a9"]
}, Open  ]],
Cell[171701, 3559, 660, 12, 53, "Text",ExpressionUUID->"6f1c16bb-0dbd-4532-92fb-70ae6bc1761d"],
Cell[172364, 3573, 668, 18, 30, "Input",ExpressionUUID->"627d86bf-36e7-4379-88d0-43ee1865f77e"],
Cell[173035, 3593, 728, 13, 53, "Text",ExpressionUUID->"3f015b35-648d-4afe-84ef-6d5158bae492"],
Cell[CellGroupData[{
Cell[173788, 3610, 310, 5, 30, "Input",ExpressionUUID->"64a90a4b-fc6d-499d-a26e-0158bbf1d895"],
Cell[174101, 3617, 65899, 1125, 272, "Output",ExpressionUUID->"187bbe8c-f5c5-410b-bca9-de2ef40b805b"]
}, Open  ]]
}
]
*)

